<?php if ( ! defined( 'ABSPATH' ) ) die( 'Forbidden' );

use PrivateArea\Core;
use PrivateArea\Settings;
use PrivateArea\Utils\Notice;
use PrivateArea\AccessHandler;
use PrivateArea\AccessController;

/**
 * Plugin Name: WP Private Area
 * Description: Enable a private area on your website.
 * Version: 1.0.1
 * Plugin URI: https://justevolve.it/downloads/private-area/
 * Author: Evolve
 * Author URI: https://justevolve.it
 * License: GPL2
 * Text Domain: wp-private-area
 * Domain Path: /languages/
 *
 * Private Area is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 *
 * Private Area is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @package   Private Area
 * @author 	  Evolve <info@justevolve.it>
 * @copyright Copyright (c) 2020
 * @license   http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */

/* Class autoloader. */
require_once __DIR__ . '/vendor/autoload.php';

/**
 * Plugin setup.
 *
 * @since 1.0.0
 */
function wp_private_area_setup() {
	$core = Core::get_instance();

	/* Set the plugin class environment variables. */
	$core->set_version( '1.0.1' );
	$core->set_path( trailingslashit( __DIR__ ) );
	$core->set_uri( trailingslashit( plugin_dir_url( __FILE__ ) ) );

	/* Set the access controller. */
	$access_controller = new AccessController();
	$access_controller->declare_template();
	$core->set_access_controller( $access_controller );

	/* Set the access handler. */
	$access_handler = new AccessHandler();
	$core->set_access_handler( $access_handler );

	/* Create the plugin's settings page. */
	$settings = new Settings();
	$settings->create_page();
	$core->set_settings( $settings );

	/* Lock private pages. */
	$core->lock_pages();

	/* Maybe disable the admin bar. */
	$core->maybe_disable_admin_bar();

	/* Maybe redirect users after loggin in. */
	$core->maybe_redirect_after_login();

	/* Notices. */
	$suggestion_notice = new Notice( 'feature_suggestion', sprintf(
		__( 'If you think you have a great idea that could <strong>make Private Area even better</strong>, don\'t hesitate to tell us and we\'ll include it as a plugin update! <a href="%s" _target="blank">%s</a>', 'wp-private-area' ),
		esc_attr( 'https://docs.google.com/forms/d/e/1FAIpQLSfjhLRn3Bgg5cDuZXRM1PjQB9PPpHdXttE4QtE5XLVkyfTkjQ/viewform' ),
		esc_html__( 'Suggest a feature!', 'wp-private-area' )
	) );
}

if ( function_exists( 'add_action' ) ) {
	/**
	 * Setup the plugin only when all active plugins have loaded.
	 *
	 * @since 1.0.0
	 */
	add_action( 'plugins_loaded', function() {
		/* Load the text domain. */
		\load_plugin_textdomain( 'wp-private-area', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

		\wp_private_area_setup();
	} );
}
