<?php

namespace PrivateArea;

if ( ! defined( 'ABSPATH' ) ) die( 'Forbidden' );

/**
 * Controller abstract class.
 *
 * This abstract class is entitled to define a structure that controllers must
 * adhere to before being injected into the chain of possible private page
 * access controls.
 *
 * @since 1.0.0
 */
abstract class Controller {

	/**
	 * The access settings.
	 *
	 * @var array
	 */
	protected $settings = [];

	/**
	 * Get the name of the controller.
	 *
	 * @since 1.0.0
	 * @return string
	 */
	public abstract function get_name();

	/**
	 * Set the access settings.
	 *
	 * @since 1.0.0
	 * @param array $settings The settings array.
	 */
	public function set_settings( array $settings ) {
		$this->settings = $settings;
	}

	/**
	 * Access level HTML name attribute.
	 *
	 * @since 1.0.0
	 * @param int $page_id The page ID.
	 * @param string $suffix The name attribute suffix.
	 * @return string
	 */
	protected function access_level_name( int $page_id, string $suffix = '' ) {
		return 'access_level[' . $page_id . '][' . $this->get_name() . ']' . $suffix;
	}

	/**
	 * Setup the controller data.
	 *
	 * @since 1.0.0
	 */
	public abstract function setup();

	/**
	 * Check if the current visitor is entitled to access the current screen.
	 *
	 * @since 1.0.0
	 * @return bool
	 */
	public abstract function check();

}
